@@ -5,10 +5,18 @@ from flask import jsonify, request, Response
 
 from blueflask.lib.infos import no_content
 
-from ...db import connexion
+from rest_client import RestClient
+
+# from ...db import connexion
 from ...channel import Channel
 from ...program import ProgramGuide
-from ...consts import DB_CREDENTIALS, LOGS, CATEGORIE, CHANNEL_LIST
+from ...consts import (
+    LOGS,
+    CATEGORIE,
+    CHANNEL_LIST,
+    TMIRA,
+    CH  # ,DB_CREDENTIALS
+    )
 from . import api
 
 import datetime
@@ -37,55 +45,110 @@ def categories_channels():
     return jsonify(CATEGORIE)
 
 
+# @api.route('/programs', methods=['GET'])
+# def program_by_day():
+#     data = request.get_json()
+#     if data.get("channel"):
+#         sql = (
+#             """select * from program where"""
+#             """ date_trunc('day',start)='{}' and channel='{}'""".format(
+#                 data["date"],
+#                 data["channel"]
+#                 )
+#             )
+#     else:
+#         sql = (
+#             """select * from program where"""
+#             """ date_trunc('day',start)='{}'""".format(
+#                 data["date"]
+#                 )
+#             )
+#     LOGS.logger.info(sql)
+#     programs = {}
+#     try:
+#         con = connexion(**DB_CREDENTIALS)
+#         cursor = con.cursor()
+#         cursor.execute(sql)
+#     except Exception as e:
+#         LOGS.logger.info(e)
+#     else:
+#         result = cursor.fetchall()
+#         LOGS.logger.info(result)
+#         if result:
+#             channels = set(map(lambda x: x[4], result))
+#             for channel in channels:
+#                 categorie = get_categorie(channel)
+#                 if programs.get(categorie):
+#                     programs[categorie].update({channel: []})
+#                 else:
+#                     programs[categorie] = {channel: []}
+#                 for i in result:
+#                     if i[4] == channel:
+#                         program = {
+#                             "service_id": i[3],
+#                             "start": i[1],
+#                             "stop": i[2],
+#                             "title": i[5],
+#                             "description": i[6]
+#                         }
+#                         (programs[categorie][channel]).append(program)
+#         cursor.close()
+#         con.close()
+#     return jsonify(programs)
+
+
 @api.route('/programs', methods=['GET'])
 def program_by_day():
     data = request.get_json()
+    LOGS.logger.info(data)
     if data.get("channel"):
-        sql = (
-            """select * from program where"""
-            """ date_trunc('day',start)='{}' and channel='{}'""".format(
-                data["date"],
-                data["channel"]
+        programs = {}
+        categorie = get_categorie(data["channel"])
+        programs[categorie] = {data["channel"]: []}
+        channel_id = CH.get(data["channel"])
+        date = (data["date"]).replace("-", "")
+        client = RestClient(TMIRA)
+        LOGS.logger.info("{}-{}".format(channel_id, date))
+        infos = client.get(
+            '/{}/xmls/{}.xml'.format(
+                channel_id,
+                date
                 )
             )
-    else:
-        sql = (
-            """select * from program where"""
-            """ date_trunc('day',start)='{}'""".format(
-                data["date"]
-                )
-            )
-    LOGS.logger.info(sql)
-    programs = {}
-    try:
-        con = connexion(**DB_CREDENTIALS)
-        cursor = con.cursor()
-        cursor.execute(sql)
-    except Exception as e:
-        LOGS.logger.info(e)
-    else:
-        result = cursor.fetchall()
+        result = xmltodict.parse(infos["content"])
         LOGS.logger.info(result)
-        if result:
-            channels = set(map(lambda x: x[4], result))
-            for channel in channels:
-                categorie = get_categorie(channel)
-                if programs.get(categorie):
-                    programs[categorie].update({channel: []})
+        if result.get("BroadcastData"):
+            pg = (
+                result["BroadcastData"]["ScheduleData"]
+                ["ChannelPeriod"]["Event"]
+                )
+            i = 0
+            while i <= (len(pg)-1):
+                if i == (len(pg)-1):
+                    stop = (
+                        result["BroadcastData"]["ScheduleData"]
+                        ["ChannelPeriod"]["@endTime"]
+                        )
                 else:
-                    programs[categorie] = {channel: []}
-                for i in result:
-                    if i[4] == channel:
-                        program = {
-                            "service_id": i[3],
-                            "start": i[1],
-                            "stop": i[2],
-                            "title": i[5],
-                            "description": i[6]
-                        }
-                        (programs[categorie][channel]).append(program)
-        cursor.close()
-        con.close()
+                    stop = pg[i+1]["@beginTime"]
+                program = {
+                    "service_id": (
+                        result["BroadcastData"]["ScheduleData"]
+                        ["ChannelPeriod"]["ChannelId"]
+                        ),
+                    "start": pg[i]["@beginTime"],
+                    "stop": stop,
+                    "title": pg[i]["EpgProduction"]["EpgText"]["Name"],
+                    "description": (
+                        pg[i]["EpgProduction"]
+                        ["EpgText"]["Description"]
+                        )
+                    }
+                (programs[categorie][data["channel"]]).append(program)
+                i += 1
+        else:
+            programs[categorie][data["channel"]] = []
+    LOGS.logger.info(programs)
     return jsonify(programs)
 
 
