@@ -90,7 +90,6 @@ CHANNEL_LIST = {
     "44": {"name": "France O"},
     "45": {"name": "E!"},
     "46": {"name": "TFX"},
-    "47": {"name": "SERIES"},
     "48": {"name": "Passions TV"},
     "49": {"name": "RTL9"},
     "50": {"name": "MCM"},
@@ -117,8 +116,6 @@ CHANNEL_LIST = {
     "80": {"name": "TCM Cinema"},
     "82": {"name": "Crime District"},
     "83": {"name": "Action"},
-    "85": {"name": "CTV"},
-    "86": {"name": "CTV 2"},
     "90": {"name": "Fashion TV"},
     "501": {"name": "France Info"},
     "502": {"name": "France Culture"},
@@ -129,7 +126,7 @@ CHANNEL_LIST = {
     }
 
 CATEGORIE = {
-    "Malagasy": [
+    "Malgache": [
         "VIVA",
         "RTA",
         "Dream'In",
@@ -139,8 +136,6 @@ CATEGORIE = {
         ],
     "Cinéma": [
         "TCM Cinema",
-        "CTV",
-        "CTV2",
         "Action"
         ],
     "Information": [
@@ -152,6 +147,7 @@ CATEGORIE = {
         "AfricaNews"
         ],
     "Généraliste": [
+        "TF1",
         "France 2",
         "France 3",
         "France 5",
@@ -197,7 +193,6 @@ CATEGORIE = {
         "AB3",
         "RTL9",
         "E!",
-        "SERIES",
         "Passions TV",
         "TFX",
         "Crime District",
@@ -224,7 +219,7 @@ CACHE = {
     "3": {"name": "RTA"},
     "4": {"name": "RECORD TV"},
     "5": {"name": "VIVA"},
-    "6": {"name": "i-BC"},
+    "6": {"name": "IBC"},
     "7": {"name": "Dream'In"},
     "8": {"name": "STREAMING"},
     "9": {"name": "Chaine du mois"},
@@ -255,7 +250,7 @@ CACHE = {
     "36": {"name": "TOONAMI"},
     "37": {"name": "Tivi5MONDE"},
     "38": {"name": "Mangas"},
-    "39": {"name": "English Club TV"},
+    "39": {"name": "ECTV"},
     "40": {"name": "ES1"},
     "41": {"name": "AB1"},
     "42": {"name": "Nina TV"},
@@ -263,7 +258,6 @@ CACHE = {
     "44": {"name": "France O"},
     "45": {"name": "E!"},
     "46": {"name": "TFX"},
-    "47": {"name": "SERIES"},
     "48": {"name": "Passions TV"},
     "49": {"name": "RTL9"},
     "50": {"name": "MCM"},
@@ -290,8 +284,6 @@ CACHE = {
     "80": {"name": "TCM Cinema"},
     "82": {"name": "Crime District"},
     "83": {"name": "Action"},
-    "85": {"name": "CTV"},
-    "86": {"name": "CTV 2"},
     "90": {"name": "Fashion TV"},
     "109": {"name": "DORCEL TV"},
     "501": {"name": "France Info"},
@@ -318,8 +310,6 @@ CH = {
     'Boomerang': '35',
     'CCTV-4': '27',
     'CNN': '25',
-    'CTV': '85',
-    'CTV2': '86',
     'Canal J': '33',
     'Cartoon Network': '31',
     'Chaine du mois': '9',
@@ -360,7 +350,6 @@ CH = {
     'RFM TV': '53',
     'RTA': '3',
     'RTL9': '49',
-    'SERIES': '47',
     'STREAMING': '8',
     'Science et Vie TV': '72',
     'TCM Cinema': '80',
