@@ -107,6 +107,10 @@ class EpgSource(object):
                     [('@lang', 'fr'), ('#text', i['title'])]
                             )
                 i = collections.OrderedDict(i)
+            if type(i["title"]) == list:
+                title = i["title"][1]
+                title["@lang"] = "fr"
+                i["title"] = title
             if dict(i)['@start'] == dict(i)['@stop']:
                 pass
             else:
